@@ -21,7 +21,6 @@ from user_management.models.tests.utils import APIRequestTestCase
 
 User = get_user_model()
 TEST_SERVER = 'http://testserver'
-THROTTLE_RATE_PATH = 'rest_framework.throttling.ScopedRateThrottle.THROTTLE_RATES'
 
 
 class GetTokenTest(APIRequestTestCase):
@@ -88,24 +87,6 @@ class GetTokenTest(APIRequestTestCase):
 
         self.assertEqual(response.status_code, status.HTTP_405_METHOD_NOT_ALLOWED)
 
-    @patch(THROTTLE_RATE_PATH, new={'logins': '1/minute'})
-    def test_user_auth_throttle(self):
-        """Ensure POST requests are throttled correctly."""
-        data = {
-            'username': 'jimmy@example.com',
-            'password': 'password;lol',
-        }
-        request = self.create_request('post', auth=False, data=data)
-        view = self.view_class.as_view()
-
-        # no token attached hence HTTP 400
-        response = view(request)
-        self.assertEqual(response.status_code, status.HTTP_400_BAD_REQUEST)
-
-        # request should be throttled now
-        response = view(request)
-        self.assertEqual(response.status_code, status.HTTP_429_TOO_MANY_REQUESTS)
-
 
 class TestRegisterView(APIRequestTestCase):
     view_class = views.UserRegister
@@ -230,23 +211,6 @@ class TestPasswordResetEmail(APIRequestTestCase):
 
         send_email.assert_called_once_with(user)
 
-    @patch(THROTTLE_RATE_PATH, new={'passwords': '1/minute'})
-    def test_post_rate_limit(self):
-        """Ensure the POST requests are rate limited."""
-        email = 'exists@example.com'
-        UserFactory.create(email=email)
-
-        data = {'email': email}
-        request = self.create_request('post', data=data, auth=False)
-        view = self.view_class.as_view()
-
-        response = view(request)
-        self.assertEqual(response.status_code, status.HTTP_204_NO_CONTENT)
-
-        # request is throttled
-        response = view(request)
-        self.assertEqual(response.status_code, status.HTTP_429_TOO_MANY_REQUESTS)
-
     def test_authenticated(self):
         request = self.create_request('post', auth=True)
         view = self.view_class.as_view()
